@@ -22,8 +22,18 @@ test_that("dbGetRowCount works with live database", {
 
 test_that("dbGetRowCount works with mock", {
   conn <- setup_mock_connection()
-  with_mock(
-    `httr::POST` = mock_httr_replies(
+  with_mocked_bindings(
+    {
+      result <- dbSendQuery(conn, "SELECT n FROM two_rows")
+      expect_equal(dbGetRowCount(result), 0)
+      expect_equal(dbFetch(result), tibble::tibble(n = 1))
+      expect_equal(dbGetRowCount(result), 1)
+      expect_equal(dbFetch(result), tibble::tibble(n = 2))
+      expect_equal(dbGetRowCount(result), 2)
+      expect_equal(dbFetch(result), tibble::tibble())
+      expect_equal(dbGetRowCount(result), 2)
+    },
+    httr_POST = mock_httr_replies(
       mock_httr_response(
         "http://localhost:8000/v1/statement",
         status_code = 200,
@@ -32,7 +42,7 @@ test_that("dbGetRowCount works with mock", {
         next_uri = "http://localhost:8000/query_1/1"
       )
     ),
-    `httr::GET` = mock_httr_replies(
+    httr_GET = mock_httr_replies(
       mock_httr_response(
         "http://localhost:8000/query_1/1",
         status_code = 200,
@@ -46,16 +56,6 @@ test_that("dbGetRowCount works with mock", {
         data = data.frame(n = 2, stringsAsFactors = FALSE),
         state = "FINISHED"
       )
-    ),
-    {
-      result <- dbSendQuery(conn, "SELECT n FROM two_rows")
-      expect_equal(dbGetRowCount(result), 0)
-      expect_equal(dbFetch(result), tibble::tibble(n = 1))
-      expect_equal(dbGetRowCount(result), 1)
-      expect_equal(dbFetch(result), tibble::tibble(n = 2))
-      expect_equal(dbGetRowCount(result), 2)
-      expect_equal(dbFetch(result), tibble::tibble())
-      expect_equal(dbGetRowCount(result), 2)
-    }
+    )
   )
 })
