@@ -24,8 +24,21 @@ test_that("fetch works with live database", {
 
 test_that("fetch works with mock", {
   conn <- setup_mock_connection()
-  with_mock(
-    `httr::POST` = mock_httr_replies(
+  with_mocked_bindings(
+    {
+      result <- dbSendQuery(conn, "SELECT 1 AS n")
+      expect_error(
+        fetch(result, 1),
+        ".*fetching custom number of rows.*is not supported.*"
+      )
+      expect_equal(fetch(result), tibble::tibble(n = 1))
+      expect_equal(fetch(result, -1), tibble::tibble(n = 2))
+      expect_true(dbHasCompleted(result))
+
+      result <- dbSendQuery(conn, "SELECT 1 AS n")
+      expect_equal(fetch(result, -1), tibble::tibble(n = c(1, 2)))
+    },
+    httr_POST = mock_httr_replies(
       mock_httr_response(
         "http://localhost:8000/v1/statement",
         status_code = 200,
@@ -34,7 +47,7 @@ test_that("fetch works with mock", {
         next_uri = "http://localhost:8000/query_1/1"
       )
     ),
-    `httr::GET` = mock_httr_replies(
+    httr_GET = mock_httr_replies(
       mock_httr_response(
         "http://localhost:8000/query_1/1",
         status_code = 200,
@@ -48,19 +61,6 @@ test_that("fetch works with mock", {
         data = data.frame(n = 2),
         state = "FINISHED"
       )
-    ),
-    {
-      result <- dbSendQuery(conn, "SELECT 1 AS n")
-      expect_error(
-        fetch(result, 1),
-        ".*fetching custom number of rows.*is not supported.*"
-      )
-      expect_equal(fetch(result), tibble::tibble(n = 1))
-      expect_equal(fetch(result, -1), tibble::tibble(n = 2))
-      expect_true(dbHasCompleted(result))
-
-      result <- dbSendQuery(conn, "SELECT 1 AS n")
-      expect_equal(fetch(result, -1), tibble::tibble(n = c(1, 2)))
-    }
+    )
   )
 })
